/*
 * ------------------------------------------------------------------------
 *
 *  Copyright by KNIME AG, Zurich, Switzerland
 *  Website: http://www.knime.com; Email: contact@knime.com
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME AG herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * ---------------------------------------------------------------------
 *
 * History
 *   01.11.2016 (andisadewi): created
 */
package org.knime.ext.textprocessing.nodes.preprocessing.stanfordlemmatizer;

import org.knime.core.node.InvalidSettingsException;
import org.knime.core.node.streamable.simple.SimpleStreamableOperatorInternals;

/**
 * Helper class to represent a warning message that is stored in SimpleStreamableOperatorInternals-object.
 *
 * @author Andisa Dewi, KNIME.com, Berlin, Germany
 */
final class WarningMessage extends SimpleStreamableOperatorInternals {
    private static final String CONFIG_KEY = "warningmessage";

    /**
     * @return the warning message, can be <code>null</code>
     */
    String get() {
        try {
            return this.getConfig().getString(CONFIG_KEY).trim();
        } catch (InvalidSettingsException e) {
            return null;
        }
    }

    void set(final String message) {
        this.getConfig().addString(CONFIG_KEY, message);
    }

    /**
     * Appends the given warning message to existing ones and puts a '\n' in between. Or sets the given message if no
     * message was set so far.
     */
    void append(final String message) {
        try {
            if (this.getConfig().getString(CONFIG_KEY) == null) {
                set("");
            }
        } catch (InvalidSettingsException e) {
            set("");
        }

        try {
            this.getConfig().addString(CONFIG_KEY, this.getConfig().getString(CONFIG_KEY) + message + "\n");
        } catch (InvalidSettingsException e) {
            // should not happen
            throw new RuntimeException(e);
        }
    }

}
